@@ -1,7 +1,7 @@
 package Test::Rinci;
 
-our $DATE = '2016-02-21'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2016-03-06'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -74,7 +74,9 @@ sub _test_function_metadata {
             $i++;
             next unless $eg->{test} // 1;
             $Test->subtest(
-                "example #$i" . ($eg->{summary} ? " ($eg->{summary})" : ""),
+                "example #$i" .
+                    ($eg->{name} ? " ($eg->{name})" :
+                     ($eg->{summary} ? " ($eg->{summary})" : "")),
                 sub {
                     my $args;
                     if ($eg->{args}) {
@@ -321,7 +323,7 @@ Test::Rinci - Test Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.13 of Test::Rinci (from Perl distribution Test-Rinci), released on 2016-02-21.
+This document describes version 0.14 of Test::Rinci (from Perl distribution Test-Rinci), released on 2016-03-06.
 
 =head1 SYNOPSIS
 
